@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "abstractaddressbook.h"
 #include "abstractdisplayinfo.h"
@@ -68,7 +55,7 @@ void AbstractAddressBook::createGroup(const KContacts::ContactGroup &group)
         item.setPayload<KContacts::ContactGroup>(group);
         item.setMimeType(KContacts::ContactGroup::mimeType());
 
-        Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob(item, mCollection);
+        auto *job = new Akonadi::ItemCreateJob(item, mCollection);
         connect(job, &Akonadi::ItemCreateJob::result, this, &AbstractAddressBook::slotStoreDone);
     }
 }
@@ -89,7 +76,7 @@ void AbstractAddressBook::createContact(const KContacts::Addressee &address)
         Akonadi::Item item;
         item.setPayload<KContacts::Addressee>(address);
         item.setMimeType(KContacts::Addressee::mimeType());
-        Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob(item, mCollection);
+        auto *job = new Akonadi::ItemCreateJob(item, mCollection);
         connect(job, &Akonadi::ItemCreateJob::result, this, &AbstractAddressBook::slotStoreDone);
     }
 }
